%% Plotting droplet distribution
clc
close all

%% Reading data from excel files
T = readtable('DropletDistribution1.xlsx'); % This contains 50% and 75% opening
T2 = readtable('DropletDistribution2.xlsx'); % This contains 40% opening
T3 = readtable('DropletDistribution3.xlsx'); % This contains 100% opening
T4 = readtable('30%.xlsx');
T5 = readtable('20%.xlsx');

%%
N = 30; % Total number of measurements first file
N2 = 15; % Total number of measurements second file
N3 = 15;
N4 = 15;
N5 = 15;

size = T{:,1};  % x-values are the same, gives droplet size
um10 = 55;  % Droplet size limits
um100 = 99;

relevantSize = T{um10:um100,1};  % relevant size area 10-100
lowSize = T{1:um10,1};    % too small droplets

% Correction Factor 1.19948 to make it 100%
c = 1.19948;

%% Gathering y-values
samples = [];
for i = 0:N-1
   samplei = T{:,2+3*i}./c;    % These are the columns giving the volume percentage
   samples = [samples,samplei];
end

samples2 = [];
for i = 0:N2-1
   samplei2 = T2{:,2+3*i}./c;    
   samples2 = [samples2,samplei2];
end

samples3 = [];
for i = 0:N3-1
   samplei3 = T3{:,2+3*i}./c;    
   samples3 = [samples3,samplei3];
end

samples4 = [];
for i = 0:N4-1
   samplei4 = T4{:,2+3*i}./c;    
   samples4 = [samples4,samplei4];
end

samples5 = [];
for i = 0:N5-1
   samplei5 = T5{:,2+3*i}./c;    
   samples5 = [samples5,samplei5];
end

%% Plotting
%% 50%
figure
for i = 1:15
    plot(size, samples(:,i))
    hold on
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 7])
title('Droplet distribution 50% valve opening')
saveas(gcf,'DropletDistribution50','epsc')

figure
for i = 1:15
    semilogx(size, samples(:,i))
    hold on
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 7])
grid on
title('Droplet distribution 50% valve opening')
saveas(gcf,'DropletDistributionLog50','epsc')

%% 75%
figure
for i = 16:30
    plot(size, samples(:,i))
    hold on
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
title('Droplet distribution 75% valve opening')
saveas(gcf,'DropletDistribution75','epsc')

figure
for i = 16:30
    semilogx(size, samples(:,i),'HandleVisibility','off')
    hold on
    area(relevantSize, samples(um10:um100,i),'FaceColor', 'b')
    hold on 
    area(lowSize, samples(1:um10,i), 'FaceColor', 'r')
    hold on
    Area75 = trapz(samples(um10:um100,i));
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
legend('Separable', 'Inseparable')
legend('Location','northwest')
title('Droplet distribution 75% valve opening')
saveas(gcf,'DropletDistributionLog75','epsc')

%% 40% 
figure
for i = 1:15
    plot(size(1:99), samples2(:,i))
    hold on
    Area40 = trapz(samples2(um10:um100,i));
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
title('Droplet distribution 40% valve opening')
saveas(gcf,'DropletDistribution40','epsc')

figure
for i = 1:15
    semilogx(size(1:99), samples2(:,i),'HandleVisibility','off')
    hold on
    area(relevantSize, samples2(um10:um100,i),'FaceColor', 'b')
    hold on 
    area(lowSize, samples2(1:um10,i), 'FaceColor', 'r')
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
legend('Separable', 'Inseparable')
legend('Location','northwest')
title('Droplet distribution 40% valve opening')
saveas(gcf,'DropletDistributionLog40','epsc')

%% 100%
figure
for i = 1:15
    plot(size(1:99), samples3(:,i))
    hold on
    Area100 = trapz(samples3(um10:um100,i));
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])

title('Droplet distribution 100% valve opening')
saveas(gcf,'DropletDistribution100','epsc')

figure
for i = 1:15
    semilogx(size(1:99), samples3(:,i),'HandleVisibility','off')
    hold on
    area(relevantSize, samples3(um10:um100,i),'FaceColor', 'b')
    hold on 
    area(lowSize, samples3(1:um10,i), 'FaceColor', 'r')
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
legend('Separable', 'Inseparable')
legend('Location','northwest')
title('Droplet distribution 100% valve opening')
saveas(gcf,'DropletDistributionLog100','epsc')

%% 30%
figure
for i = 1:15
    plot(size(1:99), samples4(:,i))
    hold on
    Area30 = trapz(samples4(um10:um100,i));
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
title('Droplet distribution 30% valve opening')
saveas(gcf,'DropletDistribution30','epsc')

figure
for i = 1:15
    semilogx(size(1:99), samples4(:,i), 'HandleVisibility','off')
    hold on
    area(relevantSize, samples4(um10:um100,i),'FaceColor', 'b')
    hold on 
    area(lowSize, samples4(1:um10,i), 'FaceColor', 'r')
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
legend('Separable', 'Inseparable')
legend('Location','northwest')
grid on
title('Droplet distribution 30% valve opening')
saveas(gcf,'DropletDistributionLog30','epsc')

%% 20%
figure
for i = 1:15
    plot(size(1:99), samples5(:,i))
    hold on
    Area20 = trapz(samples5(um10:um100,i));
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
title('Droplet distribution 20% valve opening')
saveas(gcf,'DropletDistribution20','epsc')

figure
for i = 1:15
    semilogx(size(1:99), samples5(:,i), 'HandleVisibility','off')
    hold on
    area(relevantSize, samples5(um10:um100,i),'FaceColor', 'b')
    hold on 
    area(lowSize, samples5(1:um10,i), 'FaceColor', 'r')
end

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0 150])
ylim([0 9])
legend('Separable', 'Inseparable')
legend('Location','northwest')
title('Droplet distribution 20% valve opening')
saveas(gcf,'DropletDistributionLog20','epsc')

%% Displaying percentage of area of curve which is in Separable
% AreaList = [Area20;Area30;Area40;Area50;Area75;Area100];
% disp(AreaList)

%% Average of the samples
meanSamples = [];
for i=1:length(samples)
    meanSamplei = mean(samples(i,1:15));
    meanSamples = [meanSamples;meanSamplei];
end

meanSamples1 = [];
for i=1:length(samples)
    meanSample1i = mean(samples(i,16:30));
    meanSamples1 = [meanSamples1;meanSample1i];
end

meanSamples2 = [];
for i=1:length(samples2)
    meanSample2i = mean(samples2(i,:));
    meanSamples2 = [meanSamples2;meanSample2i];
end

meanSamples3 = [];
for i=1:length(samples3)
    meanSample3i = mean(samples3(i,:));
    meanSamples3 = [meanSamples3;meanSample3i];
end

meanSamples4 = [];
for i=1:length(samples4)
    meanSample4i = mean(samples4(i,:));
    meanSamples4 = [meanSamples4;meanSample4i];
end

meanSamples5 = [];
for i=1:length(samples5)
    meanSample5i = mean(samples5(i,:));
    meanSamples5 = [meanSamples5;meanSample5i];
end

%% Plotting average curves
figure

% figure
semilogx(size,meanSamples1)
hold on
semilogx(size,meanSamples)
hold on
% semilogx(size(1:99),meanSamples2)
% hold on 
% semilogx(size(1:99),meanSamples3)
% hold on
% semilogx(size(1:99),meanSamples4)
% hold on
semilogx(size(1:99),meanSamples5)
grid on
xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
xlim([0.25 250])
ylim([0 7])
legend('Z_{in} = 75%', 'Z_{in} = 50%', 'Z_{in} = 20%')
legend('Location','northwest')
title('Droplet distribution comparison')
saveas(gcf,'DropletDistributionComparison20_50_75','epsc')
hold off

% figure
% plot(size(1:99),meanSamples4)
% hold on
% area(relevantSize, meanSamples4(um10:um100),'FaceColor', 'b')
% hold on 
% area(lowSize, meanSamples4(1:um10), 'FaceColor', 'r')
% hold on
% xline(Av4,'--r');
% hold on
% xline(12.5,'--b');
% 
% xlabel('Droplet size [\mum]')
% ylabel('Volume density [%]')
% xlim([0 150])
% ylim([0 9])
% title('Average Droplet Distribution 30%')
% grid on
% legend('V_{sep} = 54.15%', 'Separable', 'Inseparable', 'Average', 'Median')
% legend('Location','northeast')
% 
% figure
% semilogx(size(1:99),meanSamples4)
% hold on
% area(relevantSize, meanSamples4(um10:um100),'FaceColor', 'b')
% hold on 
% area(lowSize, meanSamples4(1:um10), 'FaceColor', 'r')
% hold on
% xline(Av4,'--r');
% hold on
% xline(12.5,'--b');
% Qa = trapz(meanSamples4);
% 
% xlabel('Droplet size [\mum]')
% ylabel('Volume density [%]')
% xlim([0 150])
% ylim([0 9])
% title('Average Droplet Distribution 30%')
% grid on
% legend('V_{sep} = 54.15%', 'Separable', 'Inseparable', 'Average', 'Median')
% legend('Location','northwest')
% 

%% Average value
A = size.*meanSamples;
Av = sum(A)/length(A);

A1 = size.*meanSamples1;
Av1 = sum(A1)/length(A1);

A2 = size(1:99).*meanSamples2;
Av2 = sum(A2)/length(A2);

A3 = size(1:99).*meanSamples3;
Av3 = sum(A3)/length(A3);

A4 = size(1:99).*meanSamples4;
Av4 = sum(A4)/length(A4);

A5 = size(1:99).*meanSamples5;
Av5 = sum(A5)/length(A5);

AvgList = [Av, Av1, Av2, Av3, Av4, Av5];

%% Standard deviation
var1 = [];
for i=1:length(meanSamples)
    v = (((size(i)-AvgList(1))^2)*meanSamples(i)/100);
    var1 = [var1;v];
end

var2 = [];
for i=1:length(meanSamples1)
    v = (((size(i)-AvgList(2))^2)*meanSamples1(i)/100);
    var2 = [var2;v];
end

var3 = [];
for i=1:length(meanSamples2)
    v = (((size(i)-AvgList(3))^2)*meanSamples2(i)/99);
    var3 = [var3;v];
end

var4 = [];
for i=1:length(meanSamples3)
    v = (((size(i)-AvgList(4))^2)*meanSamples3(i)/99);
    var4 = [var4;v];
end

var5 = [];
for i=1:length(meanSamples4)
    v = (((size(i)-AvgList(5))^2)*meanSamples4(i)/99);
    var5 = [var5;v];
end

var6 = [];
for i=1:length(meanSamples5)
    v = (((size(i)-AvgList(6))^2)*meanSamples5(i)/99);
    var6 = [var6;v];
end


varianceList = [sum(var1),sum(var2),sum(var3),sum(var4),sum(var5),sum(var6)];
stdList = [sqrt(varianceList(1)),sqrt(varianceList(2)),sqrt(varianceList(3)),sqrt(varianceList(4)),sqrt(varianceList(5)),sqrt(varianceList(6))];
% 
% for i=1:length(meanSamples2)
%     if meanSamples2(i) > 0
%         meanSamplesFit = [meanSamplesFit;meanSamples2(i)];
%     end
% end

%% LogNormal Distribution Estimation
muList = [];
sigmaList = [];
for i=1:length(AvgList)
    mu = log(AvgList(i)^2/(sqrt(AvgList(i)^2+varianceList(i))));
    muList = [muList;mu];
    sigma = sqrt(log(varianceList(i)/AvgList(i)^2+1));
    sigmaList = [sigmaList;sigma];
end



%% 50%
pd1 = makedist('Lognormal','mu',muList(1),'sigma',sigmaList(1));
y1 = pdf(pd1,size);
A1 = (trapz(y1));

figure
semilogx(size, meanSamples)
hold on
semilogx(size, y1*(1/A1)*100) %% scaling: y1*(1/A)*100
xlim([0.1 150])
xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
legend('True Distribution', 'Estimated Distribution')
legend('Location', 'Northwest')
title('Estimated vs True Distribution')
grid on
saveas(gcf,'EstimatedDistribution50','epsc')

%% 75%
pd2 = makedist('Lognormal','mu',muList(2),'sigma',sigmaList(2));
y2 = pdf(pd1,size);
A2 = (trapz(y2));

figure
semilogx(size, meanSamples1)
hold on
semilogx(size, y2*(1/A2)*100) %% scaling: y1*(1/A)*100
xlim([0.1 150])
xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
legend('True Distribution', 'Estimated Distribution')
legend('Location', 'Northwest')
title('Estimated vs True Distribution')
grid on
saveas(gcf,'EstimatedDistribution75','epsc')

%% 30%
pd5 = makedist('Lognormal','mu',muList(5),'sigma',sigmaList(5));
y5 = pdf(pd5,size);
A5 = (trapz(y5));

figure
semilogx(size(1:99), meanSamples4)
hold on
semilogx(size, y5*(1/A5)*100) %% scaling: y1*(1/A)*100
xlim([0.1 150])
xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
legend('True Distribution', 'Estimated Distribution')
legend('Location', 'Northwest')
title('Estimated vs True Distribution')
grid on
saveas(gcf,'EstimatedDistribution30','epsc')

%% 20%
pd6 = makedist('Lognormal','mu',muList(6),'sigma',sigmaList(6));
y6 = pdf(pd6,size);
A6 = (trapz(y6));

figure
semilogx(size(1:99), meanSamples5)
hold on
semilogx(size, y6*(1/A6)*100) %% scaling: y1*(1/A)*100
xlim([0.1 150])
xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
legend('True Distribution', 'Estimated Distribution')
legend('Location', 'Northwest')
title('Estimated vs True Distribution')
grid on
saveas(gcf,'EstimatedDistribution30','epsc')

%% Concentration
T = readtable('75%vs75%.xlsx');

N = 30; % Total number of measurements first file
c = 1.19948;

figure
semilogx(T{:,1}, T{:,2}./c)
hold on
semilogx(T{:,1}, T{:,5}./c)
hold off

xlabel('Droplet size [\mum]')
ylabel('Volume density [%]')
legend('c_v: 249 ppm','c_v: 93 ppm')
legend('Location','northwest')
xlim([0.1 200])
ylim([0 9])
grid on
title('Droplet distribution - different concentrations')
saveas(gcf,'DropletDistribution75Concentration','epsc')

%% Number distribution
T = readtable('NumberDistribution.xlsx'); 
size = T{:,1}; 
N = 12;

%% Correction Factor 1.19948 to make it 100%
c = 1.19948;

%% Gathering y-values
samples = [];
for i = 0:N-1
   samplei = T{:,2+3*i}./c;    % These are the columns giving the volume percentage
   samples = [samples,samplei];
end

%% Plotting
figure
for i = 1:N
    plot(size(1:99), samples(:,i))
    hold on
end

xlabel('Droplet size [\mum]')
ylabel('Number density [%]')
xlim([0 10])
% ylim([0 9])
title('Droplet number distribution 75% valve opening')
saveas(gcf,'NumberDistribution75','epsc')