%% Overflow estimation
clc
close all

%% Parameters
r = 0.25;   % Inner radius
c = 0.1;    % Correction factor
t = 605;
A = pi*r^2;
Cvo = 0.05;    % Valve constant
rhoOil = 793;  %kg/m^3

%% Measurements
h0 = 0.159; h1 = 0.243; h2 = 0.418; h3 = 0.575; h4 = 0.802; h5 = 1.103; h6 = 1.426; h7 = 1.741; 
h8 = 2.096; h9 = 2.3190; h10 = 2.542; h11 = 2.702; h12 = 2.951; h13 = 3.172;
h = [h0,h1,h2,h3,h4,h5,h6,h7,h8,h9,h10,h11,h12,h13];
dhList = [];

for i=1:length(h)-1
    dh = h(i+1) - h(i); 
    dhList = [dhList;dh];
end

%% Overflow valve openings
z0 = 0; z1 = 0.05; z2 = 0.10; z3 = 0.15; z4 = 0.20; z5 = 0.25; z6 = 0.30; z7 = 0.35; 
z8 = 0.40; z9 = 0.50; z10 = 0.60; z11 = 0.70; z12 = 0.80; z13 = 0.90;
zlist = [z1,z2,z3,z4,z5,z6,z7,z8,z9,z10,z11,z12,z13];

%% Measured times
t0 = 0; t1 = 604.91; t2 = 1271.1; t3 = 1793.8; t4 = 2304.2; t5 = 2937.9;    t6 = 3561.2; t7 = 4146.4; 
t8 = 4774.5; t9 = 5086.3; t10 = 5381.2; t11 = 5680.8; t12 = 5999.7; t13 = 6287.3;    
t = [t0,t1,t2,t3,t4,t5,t6,t7,t8,t9,t10,t11,t12,t13];

dtList = [];

for i=1:length(t)-1
    dt = t(i+1) - t(i); 
    dtList = [dtList;dt];
end

Qlist = [];

%% Experimentally measured overflow
for i=1:length(h)-1
    Q = A*(dhList(i))/dtList(i)*3600;
    Qlist = [Qlist;Q];
end

%% Reading data from excel file
T1 = readtable('TankLevel1.xlsx'); 

n1 = 4402;  n2 = 8501; n3 = 9952;   n4 = 13001; n5 = 14402; n6 = 15950;
n7 = 4052; n8 = 8351; n9 = 9802; n10 = 12751;
n11 = 3052; n12 = 7452; n13 = 8852; n14 = 11001; n15 = 12652; n16 = 14850;
n17 = 2702; n18 = 4901; n19 = 5852; n20 = 7400; n21 = 8283; n22 = 9251; n23 = 10552; 
n24 = 11751; n25 = 12502; n26 = 13451;

%% Mass balance (filtering the raw values in Matlab)
%% 5
f = 0.1;
Qin1 = lowpass(T1{n1:n2,2},f);
Qu1 = lowpass(T1{n1:n2,4},f);
Qo1 = Qin1-Qu1;

%% 10
Qin2 = lowpass(T1{n3:n4,2},f);
Qu2 = lowpass(T1{n3:n4,4},f);
Qo2 = Qin2-Qu2;

%% 15
Qin3 = lowpass(T1{n5:n6,2},f);
Qu3 = lowpass(T1{n5:n6,4},f);
Qo3 = Qin3-Qu3;

T2 = readtable('TankLevel2.xlsx'); 

%% 20
Qin4 = lowpass(T2{n7:n8,2},f);
Qu4 = lowpass(T2{n7:n8,4},f);
Qo4 = Qin4-Qu4;

%% 25
Qin5 = lowpass(T2{n9:n10,2},f);
Qu5 = lowpass(T2{n9:n10,4},f);
Qo5 = Qin5-Qu5;

T3 = readtable('TankLevel3.xlsx');

%% 30
Qin6 = lowpass(T3{n11:n12,4},f);
Qu6 = lowpass(T3{n11:n12,5},f);
Qo6 = Qin6-Qu6;

%% 35
Qin7 = lowpass(T3{n13:n14,4},f);
Qu7 = lowpass(T3{n13:n14,5},f);
Qo7 = Qin7-Qu7;

%% 40
Qin8 = lowpass(T3{n15:n16,4},f);
Qu8 = lowpass(T3{n15:n16,5},f);
Qo8 = Qin8-Qu8;

T4 = readtable('TankLevel4.xlsx');

%% 50
Qin9 = lowpass(T4{n17:n18,4},f);
Qu9 = lowpass(T4{n17:n18,5},f);
Qo9 = Qin9-Qu9;

%% 60
Qin10 = lowpass(T4{n19:n20,4},f);
Qu10 = lowpass(T4{n19:n20,5},f);
Qo10 = Qin10-Qu10;

%% 70
Qin11 = lowpass(T4{n21:n22,4},f);
Qu11 = lowpass(T4{n21:n22,5},f);
Qo11 = Qin11-Qu11;

%% 80
Qin12 = lowpass(T4{n23:n24,4},f);
Qu12 = lowpass(T4{n23:n24,5},f);
Qo12 = Qin12-Qu12;

%% 90
Qin13 = lowpass(T4{n25:n26,4},f);
Qu13 = lowpass(T4{n25:n26,5},f);
Qo13 = Qin13-Qu13;

%% Delta P for valve equation
dPo1 = lowpass(T1{n1:n2,3},f) - lowpass(T1{n1:n2,8},f);   % z = 0.05
dPo2 = lowpass(T1{n3:n4,3},f) - lowpass(T1{n3:n4,8},f);   % z = 0.10
dPo3 = lowpass(T1{n5:n6,3},f) - lowpass(T1{n5:n6,8},f);   % z = 0.15
dPo4 = lowpass(T2{n7:n8,3},f) - lowpass(T2{n7:n8,8},f);   % z = 0.20
dPo5 = lowpass(T2{n9:n10,3},f) - lowpass(T2{n9:n10,8},f);   % z = 0.25
dPo6 = lowpass(T3{n11:n12,6},f) - lowpass(T3{n11:n12,7},f);   % z = 0.30
dPo7 = lowpass(T3{n13:n14,6},f) - lowpass(T3{n13:n14,7},f);   % z = 0.35
dPo8 = lowpass(T3{n15:n16,6},f) - lowpass(T3{n15:n16,7},f);   % z = 0.40
dPo9 = lowpass(T4{n17:n18,6},f) - lowpass(T4{n17:n18,7},f);   % z = 0.50
dPo10 = lowpass(T4{n19:n20,6},f) - lowpass(T4{n19:n20,7},f);   % z = 0.60
dPo11 = lowpass(T4{n21:n22,6},f) - lowpass(T4{n21:n22,7},f);   % z = 0.70
dPo12 = lowpass(T4{n23:n24,6},f) - lowpass(T4{n23:n24,7},f);   % z = 0.80
dPo13 = lowpass(T4{n25:n26,6},f) - lowpass(T4{n25:n26,7},f);   % z = 0.90


%% Valve equation

Qov1 = [];
for i = 1:length(dPo1)
    Q = zlist(1)*Cvo*sqrt(2*dPo1(i)*10^5/rhoOil);
    Qov1 = [Qov1; Q];
end

Qov2 = [];
for i = 1:length(dPo2)
    Q = zlist(2)*Cvo*sqrt(2*dPo2(i)*10^5/rhoOil);
    Qov2 = [Qov2; Q];
end

Qov3 = [];
for i = 1:length(dPo3)
    Q = zlist(3)*Cvo*sqrt(2*dPo3(i)*10^5/rhoOil);
    Qov3 = [Qov3; Q];
end

Qov4 = [];
for i = 1:length(dPo4)
    Q = zlist(4)*Cvo*sqrt(2*dPo4(i)*10^5/rhoOil);
    Qov4 = [Qov4; Q];
end

Qov5 = [];
for i = 1:length(dPo5)
    Q = zlist(5)*Cvo*sqrt(2*dPo5(i)*10^5/rhoOil);
    Qov5 = [Qov5; Q];
end

Qov6 = [];
for i = 1:length(dPo6)
    Q = zlist(6)*Cvo*sqrt(2*dPo6(i)*10^5/rhoOil);
    Qov6 = [Qov6; Q];
end

Qov7 = [];
for i = 1:length(dPo7)
    Q = zlist(7)*Cvo*sqrt(2*dPo7(i)*10^5/rhoOil);
    Qov7 = [Qov7; Q];
end

Qov8 = [];
for i = 1:length(dPo8)
    Q = zlist(8)*Cvo*sqrt(2*dPo8(i)*10^5/rhoOil);
    Qov8 = [Qov8; Q];
end

Qov9 = [];
for i = 1:length(dPo9)
    Q = zlist(9)*Cvo*sqrt(2*dPo9(i)*10^5/rhoOil);
    Qov9 = [Qov9; Q];
end

Qov10 = [];
for i = 1:length(dPo10)
    Q = zlist(10)*Cvo*sqrt(2*dPo10(i)*10^5/rhoOil);
    Qov10 = [Qov10; Q];
end

Qov11 = [];
for i = 1:length(dPo11)
    Q = zlist(11)*Cvo*sqrt(2*dPo11(i)*10^5/rhoOil);
    Qov11 = [Qov11; Q];
end

Qov12 = [];
for i = 1:length(dPo12)
    Q = zlist(12)*Cvo*sqrt(2*dPo12(i)*10^5/rhoOil);
    Qov12 = [Qov12; Q];
end

Qov13 = [];
for i = 1:length(dPo13)
    Q = zlist(13)*Cvo*sqrt(2*dPo13(i)*10^5/rhoOil);
    Qov13 = [Qov13; Q];
end

%% Calculating average of estimated overflow and correcting for flowmeter error
QmeanList = [mean(Qo1)+c,mean(Qo2)+c,mean(Qo3)+c,mean(Qo4)+c,mean(Qo5)+c,mean(Qo6)+c,mean(Qo7)+c,mean(Qo8)+c,mean(Qo9)+c,mean(Qo10)+c,mean(Qo11)+c,mean(Qo12)+c,mean(Qo13)+c];

%% Calculating average of valve equation estimations
QovAvgList = [sum(Qov1)/length(Qov1);sum(Qov2)/length(Qov2);sum(Qov3)/length(Qov3);sum(Qov4)/length(Qov4);sum(Qov5)/length(Qov5);sum(Qov6)/length(Qov6);sum(Qov7)/length(Qov7);sum(Qov8)/length(Qov8);sum(Qov9)/length(Qov9);sum(Qov10)/length(Qov10);sum(Qov11)/length(Qov11);sum(Qov12)/length(Qov12);sum(Qov13)/length(Qov13)];

%% Plotting Mass balance estimated results (including correction)
figure
title('Mass balance estimation')
subplot(4,2,1)  %10
plot(Qo2+c)
hold on
yline(QmeanList(2), 'r')
hold off
xlim([0 1000])
title('10%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,2)  %20
plot(Qo4+c)
hold on
yline(QmeanList(4), 'r')
hold off
xlim([0 1000])
title('20%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,3)  %30
plot(Qo6+c)
hold on
yline(QmeanList(6), 'r')
hold off
xlim([0 1000])
title('30%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,4)  %40
plot(Qo8+c)
hold on
yline(QmeanList(8), 'r', 'Interpreter','tex')
hold off
xlim([0 1000])
title('40%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,5)  %50
plot(Qo9+c)
hold on
yline(QmeanList(9), 'r')
hold off
xlim([0 1000])
title('50%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,6)  %60
plot(Qo10+c)
hold on
yline(QmeanList(10), 'r')
hold off
xlim([0 1000])
title('60%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,7)  %70
plot(Qo11+c)
hold on
yline(QmeanList(11), 'r')
hold off
xlim([0 1000])
title('70%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,8)  %80
plot(Qo12+c)
hold on
yline(QmeanList(12), 'r')
hold off
xlim([0 1000])
title('80%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

saveas(gcf,'EstimatedOverflowMassbalance','epsc')

%% Plotting Valve equation estimated results

figure
subplot(4,2,1)  %10
plot(Qov2)
hold on
yline(QovAvgList(2), 'r')
hold off
xlim([0 1000])
title('10%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,2)  
plot(Qov4)
hold on
yline(QovAvgList(4), 'r')
hold off
xlim([0 1000])
title('20%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,3)  %30
plot(Qov6)
hold on
yline(QovAvgList(6), 'r')
hold off
xlim([0 1000])
title('30%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,4)  %40
plot(Qov8)
hold on
yline(QovAvgList(8), 'r')
hold off
xlim([0 1000])
title('40%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,5)  %50
plot(Qov9)
hold on
yline(QovAvgList(9), 'r')
hold off
xlim([0 1000])
title('50%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,6)  %60
plot(Qov10)
hold on
yline(QovAvgList(10), 'r')
hold off
xlim([0 1000])
title('60%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,7)  %70
plot(Qov11)
hold on
yline(QovAvgList(11), 'r')
hold off
xlim([0 1000])
title('70%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

subplot(4,2,8)  %80
plot(Qov12)
hold on
yline(QovAvgList(12), 'r')
hold off
xlim([0 1000])
title('80%')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')

saveas(gcf,'EstimatedOverflowValveEquation','epsc')


%% Plotting Comparison of the methods' average values
figure
scatter(zlist,Qlist,'filled')
hold on
scatter(zlist,QmeanList)
hold on
scatter(zlist,QovAvgList, 'filled')
hold off

legend('Measured', 'Mass Balance', 'Valve Equation', 'Interpreter','tex')
legend('Location','northwest')
xlabel('Z_O', 'Interpreter','tex')
ylabel('Q_O [m^3/h]', 'Interpreter','tex')
saveas(gcf,'OverflowEstimationVsTankLevel','epsc')